@@ -572,7 +572,7 @@ function perform_actions($con,$conf){
             $q = "SELECT * FROM roles WHERE name='$safe_role_name'";
             $r = mysqli_query($con, $q);
             $n = mysqli_num_rows($r);
-            if($n != 1 && $safe_role_name != "vm-net" && $safe_role_name != "ovs-bridge" && $safe_role_name != "ceph-cluster" && $safe_role_name != "ipmi"){
+            if($n != 1 && $safe_role_name != "vm-net" && $safe_role_name != "ovs-bridge" && $safe_role_name != "ceph-cluster" && $safe_role_name != "ipmi" && $safe_role_name != "vip"){
                 $out .= "Cannot find role by that name.";
                 return $out;
             }
